@@ -23,19 +23,13 @@ const _ = imports.gettext.gettext;
 const ngettext = imports.gettext.ngettext;
 
 const Champlain = imports.gi.Champlain;
-const Gio = imports.gi.Gio;
 const GLib = imports.gi.GLib;
 const GObject = imports.gi.GObject;
 
 const HVT = imports.hvt;
+const Time = imports.time;
 const Utils = imports.utils;
 
-// in org.gnome.desktop.interface
-const CLOCK_FORMAT_KEY = 'clock-format';
-
-let _desktopSettings = new Gio.Settings({ schema_id: 'org.gnome.desktop.interface' });
-let clockFormat = _desktopSettings.get_string(CLOCK_FORMAT_KEY);
-
 /*
  * These constants corresponds to the routeType attribute of transit legs
  * in original GTFS specification.
@@ -47,21 +41,21 @@ var RouteType = {
     TRAIN:       2,
     BUS:         3,
     FERRY:       4,
-    /* Cable car referres to street-level cabel cars, where the propulsive
-     * cable runs in a slot between the tracks beneeth the car
+    /* Cable car refers to street-level cabel cars, where the propulsive
+     * cable runs in a slot between the tracks beneath the car
      * https://en.wikipedia.org/wiki/Cable_car_%28railway%29
-     * For example the cable cars in San Fransisco
+     * For example the cable cars in San Francisco
      * https://en.wikipedia.org/wiki/San_Francisco_cable_car_system
      */
     CABLE_CAR:   5,
-    /* Gondola referres to a suspended cable car, typically aerial cable cars
+    /* Gondola refers to a suspended cable car, typically aerial cable cars
      * where the car is suspended from the cable
      * https://en.wikipedia.org/wiki/Gondola_lift
      * For example the "Emirates Air Line" in London
      * https://en.wikipedia.org/wiki/Emirates_Air_Line_%28cable_car%29
      */
     GONDOLA:     6,
-    /* Funicular referres to a railway system designed for steep inclines,
+    /* Funicular refers to a railway system designed for steep inclines,
      * https://en.wikipedia.org/wiki/Funicular
      */
     FUNICULAR:   7,
@@ -74,20 +68,6 @@ var RouteType = {
 /* extra time to add to the first itinerary leg when it's a walking leg */
 const WALK_SLACK = 120;
 
-const _timeFormat = new Intl.DateTimeFormat([], { hour:     '2-digit',
-                                                  minute:   '2-digit',
-                                                  hour12:   clockFormat === '12h',
-                                                  timeZone: 'UTC'});
-
-function _printTimeWithTZOffset(time, offset) {
-    let utcTimeWithOffset = time + offset;
-    let date = new Date();
-
-    date.setTime(utcTimeWithOffset);
-
-    return _timeFormat.format(date);
-}
-
 var DEFAULT_ROUTE_COLOR = '4c4c4c';
 var DEFAULT_ROUTE_TEXT_COLOR = 'ffffff';
 
@@ -279,7 +259,7 @@ class Itinerary extends GObject.Object {
             if (!leg.transit) {
                 if (i === 0) {
                     /* for the first leg subtract the walking time plus a
-                     * safty slack from the departure time of the following
+                     * safety slack from the departure time of the following
                      * leg
                      */
                     let nextLeg = this.legs[i + 1];
@@ -326,16 +306,16 @@ class Itinerary extends GObject.Object {
     _getDepartureTime() {
         /* take the itinerary departure time and offset using the timezone
          * offset of the first leg */
-        return _printTimeWithTZOffset(this.departure,
-                                      this.legs[0].agencyTimezoneOffset);
+        return Time.formatTimeWithTZOffset(this.departure,
+                                           this.legs[0].agencyTimezoneOffset);
     }
 
     _getArrivalTime() {
         /* take the itinerary departure time and offset using the timezone
          * offset of the last leg */
         let lastLeg = this.legs[this.legs.length - 1];
-        return _printTimeWithTZOffset(this.arrival,
-                                      lastLeg.agencyTimezoneOffset);
+        return Time.formatTimeWithTZOffset(this.arrival,
+                                           lastLeg.agencyTimezoneOffset);
     }
 
     prettyPrintDuration() {
@@ -770,14 +750,16 @@ var Leg = class Leg {
         /* take the itinerary departure time and offset using the timezone
          * offset of the first leg
          */
-        return _printTimeWithTZOffset(this.departure, this.agencyTimezoneOffset);
+        return Time.formatTimeWithTZOffset(this.departure,
+                                           this.agencyTimezoneOffset);
     }
 
     prettyPrintArrivalTime() {
         /* take the itinerary departure time and offset using the timezone
          * offset of the last leg
          */
-        return _printTimeWithTZOffset(this.arrival, this.agencyTimezoneOffset);
+        return Time.formatTimeWithTZOffset(this.arrival,
+                                           this.agencyTimezoneOffset);
     }
 };
 
@@ -813,14 +795,14 @@ var Stop = class Stop {
             /* take the stop arrival time and offset using the timezone
              * offset of the last leg
              */
-            return _printTimeWithTZOffset(this._arrival,
-                                          this._agencyTimezoneOffset);
+            return Time.formatTimeWithTZOffset(this._arrival,
+                                               this._agencyTimezoneOffset);
         } else {
             /* take the stop departure time and offset using the timezone
              * offset of the first leg
              */
-            return _printTimeWithTZOffset(this._departure,
-                                          this._agencyTimezoneOffset);
+            return Time.formatTimeWithTZOffset(this._departure,
+                                               this._agencyTimezoneOffset);
         }
     }
 };
